@@ -17,9 +17,6 @@ if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
-
-import sys
-
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -41,6 +38,7 @@ __all__ = (
     "RepositorySummaryTypeDef",
     "ResourcePolicyTypeDef",
     "SuccessfulPackageVersionInfoTypeDef",
+    "TagTypeDef",
     "UpstreamRepositoryInfoTypeDef",
     "AssociateExternalConnectionResultTypeDef",
     "CopyPackageVersionsResultTypeDef",
@@ -69,6 +67,7 @@ __all__ = (
     "ListPackagesResultTypeDef",
     "ListRepositoriesInDomainResultTypeDef",
     "ListRepositoriesResultTypeDef",
+    "ListTagsForResourceResultTypeDef",
     "PaginatorConfigTypeDef",
     "PutDomainPermissionsPolicyResultTypeDef",
     "PutRepositoryPermissionsPolicyResultTypeDef",
@@ -100,6 +99,7 @@ DomainDescriptionTypeDef = TypedDict(
         "encryptionKey": str,
         "repositoryCount": int,
         "assetSizeBytes": int,
+        "s3BucketArn": str,
     },
     total=False,
 )
@@ -235,6 +235,8 @@ SuccessfulPackageVersionInfoTypeDef = TypedDict(
     total=False,
 )
 
+TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str})
+
 UpstreamRepositoryInfoTypeDef = TypedDict(
     "UpstreamRepositoryInfoTypeDef", {"repositoryName": str}, total=False
 )
@@ -418,6 +420,10 @@ ListRepositoriesResultTypeDef = TypedDict(
     total=False,
 )
 
+ListTagsForResourceResultTypeDef = TypedDict(
+    "ListTagsForResourceResultTypeDef", {"tags": List["TagTypeDef"]}, total=False
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
